=== modified file 'bzrlib/tests/test_https_urllib.py'
--- bzrlib/tests/test_https_urllib.py	2016-01-27 13:36:17 +0000
+++ bzrlib/tests/test_https_urllib.py	2016-01-31 12:55:31 +0000
@@ -19,7 +19,7 @@
 """
 
 import os
-import ssl
+import sys
 
 from bzrlib import (
     config,
@@ -28,14 +28,12 @@
 from bzrlib.errors import (
     ConfigOptionValueError,
 )
-from bzrlib.tests import (
-    TestCase,
-    TestCaseInTempDir,
-)
+from bzrlib import tests
 from bzrlib.transport.http import _urllib2_wrappers
-
-
-class CaCertsConfigTests(TestCaseInTempDir):
+from bzrlib.transport.http._urllib2_wrappers import ssl
+
+
+class CaCertsConfigTests(tests.TestCaseInTempDir):
 
     def get_stack(self, content):
         return config.MemoryStack(content.encode('utf-8'))
@@ -67,7 +65,7 @@
                               "is not valid for \"ssl.ca_certs\"")
 
 
-class CertReqsConfigTests(TestCaseInTempDir):
+class CertReqsConfigTests(tests.TestCaseInTempDir):
 
     def test_default(self):
         stack = config.MemoryStack("")
@@ -82,7 +80,14 @@
         self.assertRaises(ConfigOptionValueError, stack.get, "ssl.cert_reqs")
 
 
-class MatchHostnameTests(TestCase):
+class MatchHostnameTests(tests.TestCase):
+
+    def setUp(self):
+        super(MatchHostnameTests, self).setUp()
+        if sys.version_info < (2, 7, 9):
+            raise tests.TestSkipped(
+                'python version too old to provide proper'
+                ' https hostname verification')
 
     def test_no_certificate(self):
         self.assertRaises(ValueError,

=== modified file 'bzrlib/transport/http/_urllib2_wrappers.py'
--- bzrlib/transport/http/_urllib2_wrappers.py	2016-01-29 07:01:42 +0000
+++ bzrlib/transport/http/_urllib2_wrappers.py	2016-01-31 12:55:31 +0000
@@ -56,6 +56,7 @@
 import urllib2
 import urlparse
 import re
+import ssl
 import sys
 import time
 
@@ -70,23 +71,33 @@
     transport,
     ui,
     urlutils,
-    )
-lazy_import.lazy_import(globals(), """
-import ssl
-""")
+)
+
+try:
+    _ = (ssl.match_hostname, ssl.CertificateError)
+except AttributeError:
+    # Provide fallbacks for python < 2.7.9
+    def match_hostname(cert, host):
+        trace.warning(
+            '%s cannot be verified, https certificates verification is only'
+            ' available for python versions >= 2.7.9' % (host,))
+    ssl.match_hostname = match_hostname
+    ssl.CertificateError = ValueError
 
 
 # Note for packagers: if there is no package providing certs for your platform,
 # the curl project produces http://curl.haxx.se/ca/cacert.pem weekly.
 _ssl_ca_certs_known_locations = [
-    u'/etc/ssl/certs/ca-certificates.crt', # Ubuntu/debian/gentoo
-    u'/etc/pki/tls/certs/ca-bundle.crt', # Fedora/CentOS/RH
-    u'/etc/ssl/ca-bundle.pem', # OpenSuse
-    u'/etc/ssl/cert.pem', # OpenSuse
-    u"/usr/local/share/certs/ca-root-nss.crt", # FreeBSD
+    u'/etc/ssl/certs/ca-certificates.crt',  # Ubuntu/debian/gentoo
+    u'/etc/pki/tls/certs/ca-bundle.crt',  # Fedora/CentOS/RH
+    u'/etc/ssl/ca-bundle.pem',  # OpenSuse
+    u'/etc/ssl/cert.pem',  # OpenSuse
+    u"/usr/local/share/certs/ca-root-nss.crt",  # FreeBSD
     # XXX: Needs checking, can't trust the interweb ;) -- vila 2012-01-25
-    u'/etc/openssl/certs/ca-certificates.crt', # Solaris
-    ]
+    u'/etc/openssl/certs/ca-certificates.crt',  # Solaris
+]
+
+
 def default_ca_certs():
     if sys.platform == 'win32':
         return os.path.join(os.path.dirname(sys.executable), u"cacert.pem")
@@ -115,13 +126,12 @@
 def cert_reqs_from_store(unicode_str):
     import ssl
     try:
-        return {
-            "required": ssl.CERT_REQUIRED,
-            "none": ssl.CERT_NONE
-            }[unicode_str]
+        return {"required": ssl.CERT_REQUIRED,
+                "none": ssl.CERT_NONE}[unicode_str]
     except KeyError:
         raise ValueError("invalid value %s" % unicode_str)
 
+
 def default_ca_reqs():
     if sys.platform in ('win32', 'darwin'):
         # FIXME: Once we get a native access to root certificates there, this
@@ -131,10 +141,10 @@
         return u'required'
 
 opt_ssl_ca_certs = config.Option('ssl.ca_certs',
-        from_unicode=ca_certs_from_store,
-        default=default_ca_certs,
-        invalid='warning',
-        help="""\
+                                 from_unicode=ca_certs_from_store,
+                                 default=default_ca_certs,
+                                 invalid='warning',
+                                 help="""\
 Path to certification authority certificates to trust.
 
 This should be a valid path to a bundle containing all root Certificate
@@ -144,10 +154,10 @@
 """)
 
 opt_ssl_cert_reqs = config.Option('ssl.cert_reqs',
-        default=default_ca_reqs,
-        from_unicode=cert_reqs_from_store,
-        invalid='error',
-        help="""\
+                                  default=default_ca_reqs,
+                                  from_unicode=cert_reqs_from_store,
+                                  invalid='error',
+                                  help="""\
 Whether to require a certificate from the remote side. (default:required)
 
 Possible values:
@@ -441,9 +451,10 @@
                     "'bzr help ssl.ca_certs' for more information on setting "
                     "trusted CAs.")
         try:
-            ssl_sock = ssl.wrap_socket(self.sock, self.key_file, self.cert_file,
+            ssl_sock = ssl.wrap_socket(
+                self.sock, self.key_file, self.cert_file,
                 cert_reqs=cert_reqs, ca_certs=ca_certs)
-        except ssl.SSLError, e:
+        except ssl.SSLError:
             trace.note(
                 "\n"
                 "See `bzr help ssl.ca_certs` for how to specify trusted CA"
@@ -452,14 +463,8 @@
                 "verification entirely.\n")
             raise
         if cert_reqs == ssl.CERT_REQUIRED:
-            if sys.version_info < (2, 7, 9):
-                # python2.6 doesn't provide ssl.match_hostname
-                trace.warning(
-                    'https certificates verification is only available for'
-                    ' python versions >= 2.7.9')
-            else:
-                peer_cert = ssl_sock.getpeercert()
-                ssl.match_hostname(peer_cert, host)
+            peer_cert = ssl_sock.getpeercert()
+            ssl.match_hostname(peer_cert, host)
 
         # Wrap the ssl socket before anybody use it
         self._wrap_socket_for_reporting(ssl_sock)

